==> neutronapi-0.1.4.tar.gz: neutronapi-0.1.4/neutronapi/db/connection.py <==
"""
Minimal Django-like connections manager and connection wrapper.

Provides:
- DatabaseType enum
- Connection wrapper exposing provider + execute/fetch/commit/rollback/close
- ConnectionsManager with get_connection() and a simple router
- setup_databases()/get_databases() compatibility helpers
"""
from __future__ import annotations

import os
from enum import Enum
from typing import Dict, Any, Optional

from .providers import SQLiteProvider, PostgreSQLProvider


class DatabaseType(Enum):
    SQLITE = "sqlite"
    POSTGRES = "postgres"


class DatabaseRouter:
    def __init__(self, routing_config: Optional[Dict[str, str]] = None):
        self.routing_config = routing_config or {}

    def db_for_app(self, app_label: str) -> str:
        return self.routing_config.get(app_label, 'default')


def _normalize_engine(value: str) -> str:
    """Normalize ENGINE strings to internal identifiers.
    Accepts Django-style engine paths and common aliases.
    Returns one of: 'aiosqlite' or 'asyncpg'.
    """
    e = (value or '').lower().strip()
    if e in (
        'django.db.backends.sqlite3', 'sqlite3', 'sqlite', 'aiosqlite'
    ):
        return 'aiosqlite'
    if e in (
        'django.db.backends.postgresql', 'django.db.backends.postgresql_psycopg2',
        'postgres', 'postgresql', 'psycopg2', 'asyncpg'
    ):
        return 'asyncpg'
    return e or 'aiosqlite'


class Connection:
    def __init__(self, alias: str, config: Dict[str, Any], provider):
        self.alias = alias
        self.config = config
        self.provider = provider
        engine = _normalize_engine(config.get('ENGINE', 'aiosqlite'))
        if engine not in ('aiosqlite', 'asyncpg'):
            raise ValueError(f"Unsupported database engine: {engine}. Allowed: aiosqlite, asyncpg")
        self.db_type = DatabaseType.POSTGRES if engine == 'asyncpg' else DatabaseType.SQLITE

    @classmethod
    async def create(cls, alias: str, config: Dict[str, Any]) -> 'Connection':
        engine = _normalize_engine(config.get('ENGINE', 'aiosqlite'))
        if engine not in ('aiosqlite', 'asyncpg'):
            raise ValueError(f"Unsupported database engine: {engine}. Allowed: aiosqlite, asyncpg")
        if engine == 'aiosqlite':
            provider = SQLiteProvider(config)
        elif engine == 'asyncpg':
            provider = PostgreSQLProvider(config)
        await provider.connect()
        return cls(alias, config, provider)

    # Thin wrappers for provider API
    async def execute(self, query: str, values=()):
        return await self.provider.execute(query, tuple(values))

    async def fetch_one(self, query: str, values=()):
        return await self.provider.fetchone(query, tuple(values))

    async def fetch_all(self, query: str, values=()):
        return await self.provider.fetchall(query, tuple(values))

    async def commit(self):
        # Providers auto-commit; keep for compatibility
        pass

    async def rollback(self):
        pass

    async def close(self):
        await self.provider.disconnect()


class ConnectionsManager:
    def __init__(self, config: Optional[Dict[str, Dict[str, Any]]] = None):
        # Resolve engine from env if provided (DATABASE_PROVIDER=aiosqlite|asyncpg)
        env_engine = _normalize_engine(os.getenv('DATABASE_PROVIDER', ''))
        default_engine = 'asyncpg' if env_engine == 'asyncpg' else 'aiosqlite'
        # Default to in-memory sqlite when running tests (TESTING=1)
        default_name = ':memory:' if os.getenv('TESTING', '0') == '1' else os.path.join(os.getcwd(), 'db.sqlite3')
        self.config = config or {
            'default': {
                'ENGINE': default_engine,
                'NAME': default_name,
            }
        }
        self.router = DatabaseRouter()
        self._connections: Dict[str, Connection] = {}

    async def get_connection(self, alias: str = 'default') -> Connection:
        if alias not in self._connections:
            cfg = self.config.get(alias, self.config['default'])
            self._connections[alias] = await Connection.create(alias, cfg)
        return self._connections[alias]

    async def close_all(self):
        for conn in list(self._connections.values()):
            try:
                await conn.close()
            except Exception:
                pass
        self._connections.clear()


# Global manager (Django-like)
CONNECTIONS: Optional[ConnectionsManager] = None


def setup_databases(config: Optional[Dict[str, Dict[str, Any]]] = None) -> ConnectionsManager:
    global CONNECTIONS
    CONNECTIONS = ConnectionsManager(config)
    return CONNECTIONS


def get_databases() -> ConnectionsManager:
    global CONNECTIONS
    if CONNECTIONS is None:
        CONNECTIONS = ConnectionsManager()
    return CONNECTIONS

==> neutronapi-0.2.3.tar.gz: neutronapi-0.2.3/neutronapi/db/connection.py <==
"""
Database connections manager and connection wrapper.

Provides:
- DatabaseType enum
- Connection wrapper exposing provider + execute/fetch/commit/rollback/close
- ConnectionsManager with get_connection() and a simple router
- setup_databases()/get_databases() compatibility helpers
"""
from __future__ import annotations

import os
from enum import Enum
from typing import Dict, Any, Optional

from .providers import SQLiteProvider, PostgreSQLProvider


class DatabaseType(Enum):
    SQLITE = "sqlite"
    POSTGRES = "postgres"


class DatabaseRouter:
    def __init__(self, routing_config: Optional[Dict[str, str]] = None):
        self.routing_config = routing_config or {}

    def db_for_app(self, app_label: str) -> str:
        return self.routing_config.get(app_label, 'default')


def _normalize_engine(value: str) -> str:
    """Normalize ENGINE strings to internal identifiers.
    Accepts Django-style engine paths and common aliases.
    Returns one of: 'aiosqlite' or 'asyncpg'.
    """
    e = (value or '').lower().strip()
    if e in (
        'django.db.backends.sqlite3', 'sqlite3', 'sqlite', 'aiosqlite'
    ):
        return 'aiosqlite'
    if e in (
        'django.db.backends.postgresql', 'django.db.backends.postgresql_psycopg2',
        'postgres', 'postgresql', 'psycopg2', 'asyncpg'
    ):
        return 'asyncpg'
    return e or 'aiosqlite'


class Connection:
    def __init__(self, alias: str, config: Dict[str, Any], provider):
        self.alias = alias
        self.config = config
        self.provider = provider
        engine = _normalize_engine(config.get('ENGINE', 'aiosqlite'))
        if engine not in ('aiosqlite', 'asyncpg'):
            raise ValueError(f"Unsupported database engine: {engine}. Allowed: aiosqlite, asyncpg")
        self.db_type = DatabaseType.POSTGRES if engine == 'asyncpg' else DatabaseType.SQLITE

    @classmethod
    async def create(cls, alias: str, config: Dict[str, Any]) -> 'Connection':
        engine = _normalize_engine(config.get('ENGINE', 'aiosqlite'))
        if engine not in ('aiosqlite', 'asyncpg'):
            raise ValueError(f"Unsupported database engine: {engine}. Allowed: aiosqlite, asyncpg")
        if engine == 'aiosqlite':
            provider = SQLiteProvider(config)
        elif engine == 'asyncpg':
            provider = PostgreSQLProvider(config)
        await provider.connect()
        return cls(alias, config, provider)

    # Thin wrappers for provider API
    async def execute(self, query: str, values=()):
        return await self.provider.execute(query, tuple(values))

    async def fetch_one(self, query: str, values=()):
        return await self.provider.fetchone(query, tuple(values))

    async def fetch_all(self, query: str, values=()):
        return await self.provider.fetchall(query, tuple(values))

    async def commit(self):
        # Providers auto-commit; keep for compatibility
        pass

    async def rollback(self):
        pass

    async def close(self):
        await self.provider.disconnect()


class ConnectionsManager:
    def __init__(self, config: Optional[Dict[str, Dict[str, Any]]] = None):
        # Resolve engine from env if provided (DATABASE_PROVIDER=aiosqlite|asyncpg)
        env_engine = _normalize_engine(os.getenv('DATABASE_PROVIDER', ''))
        default_engine = 'asyncpg' if env_engine == 'asyncpg' else 'aiosqlite'
        # Default to in-memory sqlite when running tests (TESTING=1)
        default_name = ':memory:' if os.getenv('TESTING', '0') == '1' else os.path.join(os.getcwd(), 'db.sqlite3')
        self.config = config or {
            'default': {
                'ENGINE': default_engine,
                'NAME': default_name,
            }
        }
        self.router = DatabaseRouter()
        self._connections: Dict[str, Connection] = {}

    async def get_connection(self, alias: str = 'default') -> Connection:
        if alias not in self._connections:
            cfg = self.config.get(alias, self.config['default'])
            self._connections[alias] = await Connection.create(alias, cfg)
        return self._connections[alias]

    async def close_all(self):
        for conn in list(self._connections.values()):
            try:
                await conn.close()
            except Exception:
                pass
        self._connections.clear()


# Global connection manager
CONNECTIONS: Optional[ConnectionsManager] = None


def setup_databases(config: Optional[Dict[str, Dict[str, Any]]] = None) -> ConnectionsManager:
    global CONNECTIONS
    CONNECTIONS = ConnectionsManager(config)
    return CONNECTIONS


def get_databases() -> ConnectionsManager:
    global CONNECTIONS
    if CONNECTIONS is None:
        CONNECTIONS = ConnectionsManager()
    return CONNECTIONS
